@@ -3,5 +3,5 @@
 #' @rdname nin
 #' @export
 `%nin%` = function(x, table) {
-  match(x, table, nomatch=0L) == 0L
+  !match(x, table, nomatch=0L)
 }
